Cross-validated eigenvalues are estimated by splitting a graph into two parts, the training and the test graph. The training graph is used to estimate eigenvectors, and the test graph is used to evaluate the correlation between the training eigenvectors and the eigenvectors of the test graph. The correlations follow a simple central limit theorem that can be used to estimate graph dimension via hypothesis testing, see Chen et al. (2021) tools:::Rd_expr_doi("10.48550/arXiv.2108.03336") for details.
Maintainer: Alex Hayes alexpghayes@gmail.com (ORCID) [copyright holder]
Authors:
Fan Chen fchen365@gmail.com (ORCID)
Karl Rohe karlrohe@wisc.edu
Useful links: